@@ -31,6 +31,7 @@ from glastopf.modules.handlers.emulators.surface import create_surface
 logger = logging.getLogger(__name__)
 package_directory = os.path.dirname(os.path.abspath(__file__))
 
+INURL_MIN_SIZE = 1000
 
 class DorkPageGenerator(object):
     """
@@ -54,7 +55,7 @@ class DorkPageGenerator(object):
         self.mnem_service = mnem_service_instance
 
         #check if we need bootstrapping
-        if len(self.database.get_dork_list('inurl')) == 0:
+        if len(self.database.get_dork_list('inurl')) <= INURL_MIN_SIZE:
             logger.info("Bootstrapping dork database.")
             self.bootstrap_dorkdb()
         self.enabled = True
@@ -71,31 +72,39 @@ class DorkPageGenerator(object):
         return line_list
 
     def generate_dork_pages(self):
-
+        new_pages = []
         line_list = self.prepare_text()
         shuffle(line_list)
 
         inurl_list = self.database.select_data()
+        shuffle(inurl_list)
         #get data from dorkdb if the live database does not have enough
-        if len(inurl_list) < 100:
-            dork_seeds = random.sample(self.database.get_dork_list('inurl'), 100)
+        if len(inurl_list) < INURL_MIN_SIZE:
+            dork_seeds = random.sample(self.database.get_dork_list('inurl'), INURL_MIN_SIZE)
             inurl_list += dork_seeds
+            assert(len(inurl_list) >= INURL_MIN_SIZE)
 
         intext_list = self.database.get_dork_list('intext')
         intitle_list = self.database.get_dork_list('intitle')
-        while len(inurl_list) > 50 and len(line_list) > 56:
+
+        # generate 5 dork pages
+        for count_new_pages in range(5):
             body = ''
-            for i in range(0, 54):
-                body += line_list.pop()
-                href = inurl_list.pop()
-                body += " <a href='%s'>%s</a> " % (href, choice(intext_list))
+            # each page has 150 dork links
+            for i in range(0, 150):
+                if len(line_list) > 0 and len(inurl_list) > 0:
+                    body += line_list.pop()
+                    href = inurl_list.pop()
+                    body += " <a href='%s'>%s</a> " % (href, choice(intext_list))
             dork_page = self.surface_creator.get_index(choice(intitle_list),
-                                                       "/index",
-                                                       body,
-                                                       "Footer Powered By")
+                                                           "/index",
+                                                           body,
+                                                           "Footer Powered By")
             page_md5 = hashlib.md5(dork_page).hexdigest()
+            new_pages.append(page_md5)
             with codecs.open("{0}/{1}".format(self.pages_path, page_md5), "w", "utf-8") as dork_file:
                 dork_file.write(dork_page)
+        return new_pages
 
     def get_current_pages(self):
         dork_page_list = []
@@ -107,27 +116,27 @@ class DorkPageGenerator(object):
                 dork_page_list.append(file_path)
         return dork_page_list
 
-    def remove_pages(self, oldpages):
-        for file_path in oldpages:
-            try:
-                os.unlink(file_path)
-            except Exception as e:
-                raise
-
     def regular_generate_dork(self, sleeper):
         sleep_time = sleeper * 60
-        old_pages = self.get_current_pages()
-        self.generate_dork_pages()
-        self.remove_pages(old_pages)
+        self._rotate_pages()
         if sleeper == 0:
             return
         if sleep_time < 60:
             sleep_time = 60
         while self.enabled:
             time.sleep(sleep_time)
-            old_pages = self.get_current_pages()
-            self.generate_dork_pages()
-            self.remove_pages(old_pages)
+            self._rotate_pages()
+
+    def _rotate_pages(self):
+        old_pages = self.get_current_pages()
+        new_pages = self.generate_dork_pages()
+
+        for file_full_path in old_pages:
+            if not os.path.basename(file_full_path) in new_pages:
+                try:
+                    os.unlink(file_full_path)
+                except Exception as e:
+                    raise
 
     def collect_dork(self, attack_event):
         if attack_event.matched_pattern != "unknown":
@@ -138,12 +147,13 @@ class DorkPageGenerator(object):
                 logger.exception("http_request split error: {0}".format(e))
 
     def bootstrap_dorkdb(self):
+        logger.debug('Bootstraping dork database.')
         ignore = ()
         dorks = []
         if self.mnem_service:
             #get dorks from mnemosyne - note: only 'inurl' at the moment
             dorks = self.mnem_service.get_dorks()
-            if len(dorks) > 0:
+            if len(dorks) >= INURL_MIN_SIZE:
                 #all went well, do not extract inurl from file
                 ignore = ('inurl')
             else:
@@ -153,3 +163,5 @@ class DorkPageGenerator(object):
         #combine mnemosyne dorks with file dorks - accordingly to the ignore filter.
         dorks += self.dork_file_processor.process_dorks(ignore)
         self.database.insert_dorks(dorks)
+        logger.debug('Finished bootstrapping dork database.')
+
