@@ -26,5 +26,6 @@ class RobotsHandler(base_emulator.BaseEmulator):
     def handle(self, attack_event):
         robots_path = os.path.join(self.data_dir, 'robots/robots.txt')
         with open(robots_path, 'r') as robot_file:
-            attack_event.response = robot_file.read()
+            response = robot_file.read()
+            attack_event.http_request.set_raw_response(response)
         return attack_event
